@@ -1,7 +1,7 @@
 use v5.20; use warnings; use experimental qw(signatures postderef);
 package Dist::Zilla::App::Command::DiffMint;
 
-our $VERSION = 'v0.1.1';
+our $VERSION = 'v0.1.2';
 
 use Dist::Zilla::App -command;
 
@@ -73,8 +73,6 @@ sub execute ($self, $opt, $arg) {
     next
       if !defined $diff;
 
-    print $diff;
-
     if ($color) {
       print { $out } _colorize($diff);
     }
@@ -180,7 +178,6 @@ sub _diff ($old, $new) {
   require Text::Diff;
   my $mode_diff = '';
   if ($new->{mode} ne $old->{mode}) {
-    warn "what the fuck $new->{mode} $old->{mode}";
     $mode_diff .= "old mode $old->{mode}\n"
       if $old->{mode};
     $mode_diff .= "new mode $new->{mode}\n"
